from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class DynamodbPointInTimeRecoveryEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that that point in time recovery is enabled for Amazon DynamoDB tables"
        id = "CKV_AWS_125"
        supported_resources = ['aws_dynamodb_table']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "point_in_time_recovery/[0]/enabled"

    def get_expected_value(self):
        return True


check = DynamodbPointInTimeRecoveryEnabled()



from .array_contains_attribute_solver import ArrayContainsAttributeSolver


class ArrayNotContainsAttributeSolver(ArrayContainsAttributeSolver):
    operator = 'not_contains'

    def __init__(self, resource_types, query_attribute, query_value):
        super().__init__(resource_types=resource_types,
                         query_attribute=query_attribute, query_value=query_value)

    def _get_operation(self, *args):
        # TODO
        raise NotImplementedError
